@@ -3,11 +3,12 @@ import os
 import re
 from hmac import compare_digest
 
-from Cryptodome.Util.strxor import strxor
 from tqdm import tqdm
 
+from .utils.strxor import strxor
+
 __all__ = [
-    "IsDirectory",
+    "IsADirectory",
     "ParseHashLineError",
     "CheckHashLineError",
     "Hasher",
@@ -21,7 +22,7 @@ _CHUNKSIZE = 0x100000  # 1 MB
 _HASH_LINE_RE = re.compile(r"([0-9a-fA-F]+) (?:\*| )?(.+)")
 
 
-class IsDirectory(OSError):
+class IsADirectory(OSError):
     """Raised by method `Hasher.calc_hash`."""
 
 
@@ -44,16 +45,16 @@ class Hasher(object):
     """General hash value generator.
 
     Generate hash values using given hash context prototype. A progressbar
-    based on `tqdm` is also available.
+    based on ``tqdm`` is also available.
 
     Parameters
     ----------
     ctx_proto : hash context
         The hash context prototype used to generate hash values.
-    chunksize : int, optional
+    chunksize : int or None, optional (default: None)
         The size of data blocks when reading data from files.
-    tqdm_args : dict, optional
-        The arguments passed to the underlying `tqdm` constructor.
+    tqdm_args : dict or None, optional (default: None)
+        The arguments passed to the underlying ``tqdm`` constructor.
     """
 
     def __init__(self, ctx_proto, *, chunksize=None, tqdm_args=None):
@@ -69,9 +70,9 @@ class Hasher(object):
         ----------
         filepath : str or path-like
             The path of a file.
-        start : int, optional
+        start : int or None, optional (default: None)
             The start offset of the file.
-        stop : int, optional
+        stop : int or None, optional (default: None)
             The stop offset of the file.
 
         Returns
@@ -80,17 +81,18 @@ class Hasher(object):
             The hash value of the file.
         """
 
-        ctx = self.ctx_proto.copy()
-        chunksize = self.chunksize
+        # Decide the range of current file. Use (0, filesize) by default.
+        # The (start, stop) will be shrinked to (0, filesize) if necessary.
         filesize = os.path.getsize(filepath)
-        # Set the range of current file.
         if start is None or start < 0:
             start = 0
         if stop is None or stop > filesize:
             stop = filesize
         if start > stop:
             raise ValueError("require start <= stop, but {} > {}".format(start, stop))
-        # Set the total of progressbar as range size.
+
+        ctx = self.ctx_proto.copy()
+        chunksize = self.chunksize
         total = stop - start
         with tqdm(total=total, **self.tqdm_args) as bar, open(filepath, "rb") as f:
             # Precompute chunk count and remaining size.
@@ -112,9 +114,9 @@ class Hasher(object):
         ----------
         dirpath : str or path-like
             The path of a directory.
-        start : int, optional
+        start : int or None, optional (default: None)
             The start offset of files belonging to the directory.
-        stop : int, optional
+        stop : int or None, optional (default: None)
             The stop offset of files belonging to the directory.
 
         Returns
@@ -142,11 +144,11 @@ class Hasher(object):
         ----------
         path : str or path-like
             The path of a file or a directory.
-        start : int, optional
+        start : int or None, optional (default: None)
             The start offset of the file or files belonging to the directory.
-        stop : int, optional
+        stop : int or None, optional (default: None)
             The stop offset of the file or files belonging to the directory.
-        dir_ok : bool, default=False
+        dir_ok : bool, optional (default: False)
             If ``True``, enable directory hashing.
 
         Returns
@@ -158,7 +160,7 @@ class Hasher(object):
         if os.path.isdir(path):
             if dir_ok:
                 return self.hash_d(path, start, stop)
-            raise IsDirectory('"{}" is a directory'.format(path))
+            raise IsADirectory("'{}' is a directory".format(path))
         return self.hash_f(path, start, stop)
 
     __call__ = hash
@@ -229,7 +231,7 @@ def generate_hash_line(path, hash_function, *, root=None):
         The path of a file or a directory with corresponding hash value.
     hash_function : callable(str or path-like) -> bytes-like
         A function for generating hash value.
-    root : str or path-like, optional
+    root : str, path-like or None, optional (default: None)
         The root directory of `path`. The path field in `hash_line` is relative
         to the root directory.
 
@@ -254,7 +256,7 @@ def check_hash_line(hash_line, hash_function, *, root=None):
         The formatted `hash_value` and `path` with GNU Coreutils style.
     hash_function : callable(str or path-like) -> bytes-like
         A function for generating hash value.
-    root : str or path-like, optional
+    root : str, path-like or None, optional (default: None)
         The root directory of `path`. The path field in `hash_line` is relative
         to the root directory.
 
