@@ -1,13 +1,14 @@
 import functools
 import os
 import sys
-from glob import iglob
 
 import click
 from click_option_group import MutuallyExclusiveOptionGroup
 
 from . import __version__
 from .core import CheckHashLineError, Hasher, check_hash_line, generate_hash_line
+from .utils.colorama import cprint, wrap_stream
+from .utils.glob import glob_scanner
 
 
 class Output(object):
@@ -17,9 +18,9 @@ class Output(object):
         if (sep and agg) or (sep and null) or (agg and null):
             raise ValueError
 
-        # Use the sep mode by default.
+        # Use the null mode by default.
         if not (sep or agg or null):
-            sep = True
+            null = True
 
         if sep:
             self._dump = self.output_sep
@@ -46,17 +47,18 @@ class Output(object):
 
 
 class GetHash(object):
-    """Provide uniform interface for cli scripts."""
+    """Provide uniform interface for CLI scripts."""
 
     def __init__(self, ctx, suffix=".sha", **kwargs):
         self.ctx = ctx
         self.suffix = suffix
 
-        self.glob_flag = kwargs.pop("glob", True)
+        self.glob_mode = kwargs.pop("glob", 1)
 
-        self.stdout = kwargs.pop("stdout", sys.stdout)
-        self.stderr = kwargs.pop("stderr", sys.stderr)
+        self.stdout = wrap_stream(kwargs.pop("stdout", sys.stdout))
+        self.stderr = wrap_stream(kwargs.pop("stderr", sys.stderr))
 
+        # Determine the path format.
         self.inplace = kwargs.pop("inplace", False)
         self.root = kwargs.pop("root", None)
 
@@ -81,29 +83,11 @@ class GetHash(object):
         )
 
     def echo(self, msg, **kwargs):
-        click.echo(msg, file=self.stdout, **kwargs)
-
-    def secho(self, msg, **kwargs):
-        click.secho(msg, file=self.stdout, **kwargs)
+        cprint(msg, file=self.stdout, **kwargs)
 
     def echo_error(self, path, exc):
-        message = "[ERROR] {}\n\t{}: {}".format(path, type(exc).__name__, exc)
-        click.secho(message, file=self.stderr, fg="red")
-
-    @property
-    def glob(self):
-        if self.glob_flag:
-            return iglob
-
-        def dummy_glob(pattern):
-            yield pattern
-
-        return dummy_glob
-
-    def scan(self, patterns):
-        for pattern in patterns:
-            for path in map(os.path.normpath, self.glob(pattern)):
-                yield path
+        msg = "[ERROR] {}\n\t{}: {}".format(path, type(exc).__name__, exc)
+        cprint(msg, file=self.stderr, fg="red")
 
     def check_root(self, path):
         if self.root is not None:
@@ -113,7 +97,7 @@ class GetHash(object):
         return None
 
     def generate_hash(self, patterns):
-        for path in self.scan(patterns):
+        for path in glob_scanner(patterns, mode=self.glob_mode):
             try:
                 root = self.check_root(path)
                 hash_line = generate_hash_line(path, self.hash_function, root=root)
@@ -123,21 +107,21 @@ class GetHash(object):
                 self.echo_error(path, e)
             else:
                 # The hash line already has a newline.
-                self.echo(hash_line, nl=False)
+                self.echo(hash_line, end="")
 
     def _check_hash(self, hash_line, hash_path):
         try:
             root = self.check_root(hash_path)
             path = check_hash_line(hash_line, self.hash_function, root=root)
         except CheckHashLineError as e:
-            self.secho("[FAILURE] {}".format(e.path), fg="red")
+            self.echo("[FAILURE] {}".format(e.path), fg="red")
         except Exception as e:
             self.echo_error(hash_path, e)
         else:
-            self.secho("[SUCCESS] {}".format(path), fg="green")
+            self.echo("[SUCCESS] {}".format(path), fg="green")
 
     def check_hash(self, patterns):
-        for hash_path in self.scan(patterns):
+        for hash_path in glob_scanner(patterns, mode=self.glob_mode):
             try:
                 with open(hash_path, "r", encoding="utf-8") as f:
                     # This function can process multiple hash lines.
@@ -171,7 +155,9 @@ def gethashcli(name):
     """Generate click decorators for the main function."""
 
     def decorator(func):
-        path_format = MutuallyExclusiveOptionGroup("Path Format")
+        path_format = MutuallyExclusiveOptionGroup(
+            "Path Format", help="Set the path format in checksum files."
+        )
         output_mode = MutuallyExclusiveOptionGroup(
             "Output Mode", help="Ignored when -c is set."
         )
@@ -190,24 +176,28 @@ def gethashcli(name):
         @click.option("--stop", type=click.INT, help="The stop offset of files.")
         @click.option(
             "--glob",
-            type=click.BOOL,
-            default=True,
-            help="Whether resolving glob patterns.",
+            type=click.IntRange(0, 2),
+            metavar="{0, 1, 2}",
+            default="1",
+            show_default=True,
+            help="Set glob mode. If ``0``, disable glob pathname pattern; if ``1``, "
+            "resolve ``*`` and ``?``; if ``2``, resolve ``*``, ``?`` and ``[]``.",
         )
         @path_format.option(
             "-i", "--inplace", is_flag=True, help="Use basename in checksum files."
         )
         @path_format.option(
-            "--root", default=None, help="Relative to root in checksum files."
+            "-z", "--root", default=None, help="Relative to root in checksum files."
         )
-        @output_mode.option("--sep", is_flag=True, help="Separate output files.")
+        @output_mode.option("-s", "--sep", is_flag=True, help="Separate output files.")
         @output_mode.option(
+            "-o",
             "--agg",
             type=click.File("w", encoding="utf-8"),
             default=None,
-            help="Specify the aggregate output file.",
+            help="Set the aggregate output file.",
         )
-        @output_mode.option("--null", is_flag=True, help="Disable output files.")
+        @output_mode.option("-n", "--null", is_flag=True, help="Disable output files.")
         @click.option("--no-stdout", is_flag=True, help="Do not output to stdout.")
         @click.option("--no-stderr", is_flag=True, help="Do not output to stderr.")
         @click.option("--tqdm-leave", type=click.BOOL, default=False, show_default=True)
